<?php

use App\Http\Controllers\Apps\PermissionManagementController;
use App\Http\Controllers\Apps\RoleManagementController;
use App\Http\Controllers\Apps\UserManagementController;
use App\Http\Controllers\Auth\SocialiteController;
use App\Http\Controllers\DashboardController;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/
Route::get('/become-client',[App\Http\Controllers\Apps\TransactionController::class,'becomeClient'])->name('become-client');
Route::post('/post-request',[App\Http\Controllers\Apps\RequestManagementController::class,'store'])->name('post-request');
Route::get('/get-otp/{id}',[App\Http\Controllers\Apps\RequestManagementController::class,'verifyOtpView'])->name('get-otp');
Route::get('/get-files/{id}',[App\Http\Controllers\Apps\RequestManagementController::class,'getFilesView'])->name('get-files');
Route::post('/verify-otp/{id}',[App\Http\Controllers\Apps\RequestManagementController::class,'otpVerification'])->name('verify-otp');
Route::post('/verify-files/{id}',[App\Http\Controllers\Apps\RequestManagementController::class,'filesVerification'])->name('verify-files');

Route::middleware(['auth', 'verified'])->group(function () {

    Route::get('/', [DashboardController::class, 'index']);

    Route::get('/dashboard', [DashboardController::class, 'index'])->name('dashboard');

    Route::prefix('agencies')->name('agencies.')->group(function(){
        Route::get('/',[App\Http\Controllers\Apps\AgencyManagementController::class,'index'])->name('index');
        Route::post('/',[App\Http\Controllers\Apps\AgencyManagementController::class,'store'])->name('store');
    });

    Route::name('user-management.')->group(function () {
        Route::resource('/user-management/users', UserManagementController::class);
        Route::resource('/user-management/roles', RoleManagementController::class);
        Route::resource('/user-management/permissions', PermissionManagementController::class);
    });

    Route::name('transactions.')->group(function () {
        Route::get('/transfer-payout', [App\Http\Controllers\Apps\TransactionController::class,'index'])->name('transfer-payout');
        Route::get('/unitary-payout', [App\Http\Controllers\Apps\TransactionController::class,'unitaryPayout'])->name('unitary-payout');
        Route::get('/cheque-payout', [App\Http\Controllers\Apps\TransactionController::class,'chequePayout'])->name('cheque-payout');
    });

    Route::prefix('requests')->name('requests.')->group(function(){
        Route::get('/',[App\Http\Controllers\Apps\RequestManagementController::class,'index'])->name('index');
    });

    Route::get('/accounts',[App\Http\Controllers\Apps\TransactionController::class,'accounts'])->name('accounts.index');


});

Route::get('/error', function () {
    abort(500);
});

Route::get('/auth/redirect/{provider}', [SocialiteController::class, 'redirect']);

require __DIR__ . '/auth.php';
